# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['HttpRouteArgs', 'HttpRoute']

@pulumi.input_type
class HttpRouteArgs:
    def __init__(__self__, *,
                 action: pulumi.Input['HttpRouteActionArgs'],
                 service_name: pulumi.Input[builtins.str],
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 frontend_id: Optional[pulumi.Input[builtins.int]] = None,
                 weight: Optional[pulumi.Input[builtins.int]] = None):
        """
        The set of arguments for constructing a HttpRoute resource.
        :param pulumi.Input['HttpRouteActionArgs'] action: Action triggered when all rules match
        :param pulumi.Input[builtins.str] service_name: The internal name of your IP load balancing
        :param pulumi.Input[builtins.str] display_name: Human readable name for your route, this field is for you
        :param pulumi.Input[builtins.int] frontend_id: Route traffic for this frontend
        :param pulumi.Input[builtins.int] weight: Route priority ([0..255]). 0 if null. Highest priority routes are evaluated first. Only the first matching route will trigger an action
        """
        pulumi.set(__self__, "action", action)
        pulumi.set(__self__, "service_name", service_name)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if frontend_id is not None:
            pulumi.set(__self__, "frontend_id", frontend_id)
        if weight is not None:
            pulumi.set(__self__, "weight", weight)

    @property
    @pulumi.getter
    def action(self) -> pulumi.Input['HttpRouteActionArgs']:
        """
        Action triggered when all rules match
        """
        return pulumi.get(self, "action")

    @action.setter
    def action(self, value: pulumi.Input['HttpRouteActionArgs']):
        pulumi.set(self, "action", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[builtins.str]:
        """
        The internal name of your IP load balancing
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Human readable name for your route, this field is for you
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="frontendId")
    def frontend_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Route traffic for this frontend
        """
        return pulumi.get(self, "frontend_id")

    @frontend_id.setter
    def frontend_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "frontend_id", value)

    @property
    @pulumi.getter
    def weight(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Route priority ([0..255]). 0 if null. Highest priority routes are evaluated first. Only the first matching route will trigger an action
        """
        return pulumi.get(self, "weight")

    @weight.setter
    def weight(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "weight", value)


@pulumi.input_type
class _HttpRouteState:
    def __init__(__self__, *,
                 action: Optional[pulumi.Input['HttpRouteActionArgs']] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 frontend_id: Optional[pulumi.Input[builtins.int]] = None,
                 rules: Optional[pulumi.Input[Sequence[pulumi.Input['HttpRouteRuleArgs']]]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 weight: Optional[pulumi.Input[builtins.int]] = None):
        """
        Input properties used for looking up and filtering HttpRoute resources.
        :param pulumi.Input['HttpRouteActionArgs'] action: Action triggered when all rules match
        :param pulumi.Input[builtins.str] display_name: Human readable name for your route, this field is for you
        :param pulumi.Input[builtins.int] frontend_id: Route traffic for this frontend
        :param pulumi.Input[Sequence[pulumi.Input['HttpRouteRuleArgs']]] rules: List of rules to match to trigger action
        :param pulumi.Input[builtins.str] service_name: The internal name of your IP load balancing
        :param pulumi.Input[builtins.str] status: Route status. Routes in "ok" state are ready to operate
        :param pulumi.Input[builtins.int] weight: Route priority ([0..255]). 0 if null. Highest priority routes are evaluated first. Only the first matching route will trigger an action
        """
        if action is not None:
            pulumi.set(__self__, "action", action)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if frontend_id is not None:
            pulumi.set(__self__, "frontend_id", frontend_id)
        if rules is not None:
            pulumi.set(__self__, "rules", rules)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if weight is not None:
            pulumi.set(__self__, "weight", weight)

    @property
    @pulumi.getter
    def action(self) -> Optional[pulumi.Input['HttpRouteActionArgs']]:
        """
        Action triggered when all rules match
        """
        return pulumi.get(self, "action")

    @action.setter
    def action(self, value: Optional[pulumi.Input['HttpRouteActionArgs']]):
        pulumi.set(self, "action", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Human readable name for your route, this field is for you
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="frontendId")
    def frontend_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Route traffic for this frontend
        """
        return pulumi.get(self, "frontend_id")

    @frontend_id.setter
    def frontend_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "frontend_id", value)

    @property
    @pulumi.getter
    def rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['HttpRouteRuleArgs']]]]:
        """
        List of rules to match to trigger action
        """
        return pulumi.get(self, "rules")

    @rules.setter
    def rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['HttpRouteRuleArgs']]]]):
        pulumi.set(self, "rules", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The internal name of your IP load balancing
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Route status. Routes in "ok" state are ready to operate
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def weight(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Route priority ([0..255]). 0 if null. Highest priority routes are evaluated first. Only the first matching route will trigger an action
        """
        return pulumi.get(self, "weight")

    @weight.setter
    def weight(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "weight", value)


@pulumi.type_token("ovh:IpLoadBalancing/httpRoute:HttpRoute")
class HttpRoute(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 action: Optional[pulumi.Input[Union['HttpRouteActionArgs', 'HttpRouteActionArgsDict']]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 frontend_id: Optional[pulumi.Input[builtins.int]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 weight: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        """
        Manage HTTP route for a loadbalancer service

        ## Example Usage

        Route which redirect all url to https.

        ```python
        import pulumi
        import pulumi_ovh as ovh

        https_redirect = ovh.ip_load_balancing.HttpRoute("https_redirect",
            service_name="loadbalancer-xxxxxxxxxxxxxxxxxx",
            display_name="Redirect to HTTPS",
            weight=1,
            action={
                "status": 302,
                "target": "https://${host}${path}${arguments}",
                "type": "redirect",
            })
        ```

        ## Import

        HTTP route can be imported using the following format `service_name` and the `id` of the route separated by "/" e.g.

        bash

        ```sh
        $ pulumi import ovh:IpLoadBalancing/httpRoute:HttpRoute httpsredirect service_name/route_id
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['HttpRouteActionArgs', 'HttpRouteActionArgsDict']] action: Action triggered when all rules match
        :param pulumi.Input[builtins.str] display_name: Human readable name for your route, this field is for you
        :param pulumi.Input[builtins.int] frontend_id: Route traffic for this frontend
        :param pulumi.Input[builtins.str] service_name: The internal name of your IP load balancing
        :param pulumi.Input[builtins.int] weight: Route priority ([0..255]). 0 if null. Highest priority routes are evaluated first. Only the first matching route will trigger an action
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: HttpRouteArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manage HTTP route for a loadbalancer service

        ## Example Usage

        Route which redirect all url to https.

        ```python
        import pulumi
        import pulumi_ovh as ovh

        https_redirect = ovh.ip_load_balancing.HttpRoute("https_redirect",
            service_name="loadbalancer-xxxxxxxxxxxxxxxxxx",
            display_name="Redirect to HTTPS",
            weight=1,
            action={
                "status": 302,
                "target": "https://${host}${path}${arguments}",
                "type": "redirect",
            })
        ```

        ## Import

        HTTP route can be imported using the following format `service_name` and the `id` of the route separated by "/" e.g.

        bash

        ```sh
        $ pulumi import ovh:IpLoadBalancing/httpRoute:HttpRoute httpsredirect service_name/route_id
        ```

        :param str resource_name: The name of the resource.
        :param HttpRouteArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(HttpRouteArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 action: Optional[pulumi.Input[Union['HttpRouteActionArgs', 'HttpRouteActionArgsDict']]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 frontend_id: Optional[pulumi.Input[builtins.int]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 weight: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = HttpRouteArgs.__new__(HttpRouteArgs)

            if action is None and not opts.urn:
                raise TypeError("Missing required property 'action'")
            __props__.__dict__["action"] = action
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["frontend_id"] = frontend_id
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            __props__.__dict__["weight"] = weight
            __props__.__dict__["rules"] = None
            __props__.__dict__["status"] = None
        super(HttpRoute, __self__).__init__(
            'ovh:IpLoadBalancing/httpRoute:HttpRoute',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            action: Optional[pulumi.Input[Union['HttpRouteActionArgs', 'HttpRouteActionArgsDict']]] = None,
            display_name: Optional[pulumi.Input[builtins.str]] = None,
            frontend_id: Optional[pulumi.Input[builtins.int]] = None,
            rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['HttpRouteRuleArgs', 'HttpRouteRuleArgsDict']]]]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            weight: Optional[pulumi.Input[builtins.int]] = None) -> 'HttpRoute':
        """
        Get an existing HttpRoute resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['HttpRouteActionArgs', 'HttpRouteActionArgsDict']] action: Action triggered when all rules match
        :param pulumi.Input[builtins.str] display_name: Human readable name for your route, this field is for you
        :param pulumi.Input[builtins.int] frontend_id: Route traffic for this frontend
        :param pulumi.Input[Sequence[pulumi.Input[Union['HttpRouteRuleArgs', 'HttpRouteRuleArgsDict']]]] rules: List of rules to match to trigger action
        :param pulumi.Input[builtins.str] service_name: The internal name of your IP load balancing
        :param pulumi.Input[builtins.str] status: Route status. Routes in "ok" state are ready to operate
        :param pulumi.Input[builtins.int] weight: Route priority ([0..255]). 0 if null. Highest priority routes are evaluated first. Only the first matching route will trigger an action
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _HttpRouteState.__new__(_HttpRouteState)

        __props__.__dict__["action"] = action
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["frontend_id"] = frontend_id
        __props__.__dict__["rules"] = rules
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["status"] = status
        __props__.__dict__["weight"] = weight
        return HttpRoute(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def action(self) -> pulumi.Output['outputs.HttpRouteAction']:
        """
        Action triggered when all rules match
        """
        return pulumi.get(self, "action")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Human readable name for your route, this field is for you
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="frontendId")
    def frontend_id(self) -> pulumi.Output[builtins.int]:
        """
        Route traffic for this frontend
        """
        return pulumi.get(self, "frontend_id")

    @property
    @pulumi.getter
    def rules(self) -> pulumi.Output[Sequence['outputs.HttpRouteRule']]:
        """
        List of rules to match to trigger action
        """
        return pulumi.get(self, "rules")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The internal name of your IP load balancing
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        Route status. Routes in "ok" state are ready to operate
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def weight(self) -> pulumi.Output[builtins.int]:
        """
        Route priority ([0..255]). 0 if null. Highest priority routes are evaluated first. Only the first matching route will trigger an action
        """
        return pulumi.get(self, "weight")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetOvhcloudConnectConfigPopDatacenterExtrasResult',
    'AwaitableGetOvhcloudConnectConfigPopDatacenterExtrasResult',
    'get_ovhcloud_connect_config_pop_datacenter_extras',
    'get_ovhcloud_connect_config_pop_datacenter_extras_output',
]

@pulumi.output_type
class GetOvhcloudConnectConfigPopDatacenterExtrasResult:
    """
    A collection of values returned by getOvhcloudConnectConfigPopDatacenterExtras.
    """
    def __init__(__self__, config_datacenter_id=None, config_pop_id=None, extra_configs=None, id=None, service_name=None):
        if config_datacenter_id and not isinstance(config_datacenter_id, float):
            raise TypeError("Expected argument 'config_datacenter_id' to be a float")
        pulumi.set(__self__, "config_datacenter_id", config_datacenter_id)
        if config_pop_id and not isinstance(config_pop_id, float):
            raise TypeError("Expected argument 'config_pop_id' to be a float")
        pulumi.set(__self__, "config_pop_id", config_pop_id)
        if extra_configs and not isinstance(extra_configs, list):
            raise TypeError("Expected argument 'extra_configs' to be a list")
        pulumi.set(__self__, "extra_configs", extra_configs)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)

    @property
    @pulumi.getter(name="configDatacenterId")
    def config_datacenter_id(self) -> builtins.float:
        """
        ID of the Datacenter Configuration
        """
        return pulumi.get(self, "config_datacenter_id")

    @property
    @pulumi.getter(name="configPopId")
    def config_pop_id(self) -> builtins.float:
        """
        ID of the Pop Configuration
        """
        return pulumi.get(self, "config_pop_id")

    @property
    @pulumi.getter(name="extraConfigs")
    def extra_configs(self) -> Sequence['outputs.GetOvhcloudConnectConfigPopDatacenterExtrasExtraConfigResult']:
        return pulumi.get(self, "extra_configs")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        """
        Service name
        """
        return pulumi.get(self, "service_name")


class AwaitableGetOvhcloudConnectConfigPopDatacenterExtrasResult(GetOvhcloudConnectConfigPopDatacenterExtrasResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetOvhcloudConnectConfigPopDatacenterExtrasResult(
            config_datacenter_id=self.config_datacenter_id,
            config_pop_id=self.config_pop_id,
            extra_configs=self.extra_configs,
            id=self.id,
            service_name=self.service_name)


def get_ovhcloud_connect_config_pop_datacenter_extras(config_datacenter_id: Optional[builtins.float] = None,
                                                      config_pop_id: Optional[builtins.float] = None,
                                                      service_name: Optional[builtins.str] = None,
                                                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetOvhcloudConnectConfigPopDatacenterExtrasResult:
    """
    Use this data source to retrieve information about an Ovhcloud Connect Datacenter Extra configuration

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    extra_cfgs = ovh.get_ovhcloud_connect_config_pop_datacenter_extras(service_name="XXX",
        config_pop_id="YYY",
        config_datacenter_id="ZZZ")
    ```


    :param builtins.float config_datacenter_id: ID of the Datacenter Configuration
    :param builtins.float config_pop_id: ID of the Pop Configuration
    :param builtins.str service_name: Service name
    """
    __args__ = dict()
    __args__['configDatacenterId'] = config_datacenter_id
    __args__['configPopId'] = config_pop_id
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:index/getOvhcloudConnectConfigPopDatacenterExtras:getOvhcloudConnectConfigPopDatacenterExtras', __args__, opts=opts, typ=GetOvhcloudConnectConfigPopDatacenterExtrasResult).value

    return AwaitableGetOvhcloudConnectConfigPopDatacenterExtrasResult(
        config_datacenter_id=pulumi.get(__ret__, 'config_datacenter_id'),
        config_pop_id=pulumi.get(__ret__, 'config_pop_id'),
        extra_configs=pulumi.get(__ret__, 'extra_configs'),
        id=pulumi.get(__ret__, 'id'),
        service_name=pulumi.get(__ret__, 'service_name'))
def get_ovhcloud_connect_config_pop_datacenter_extras_output(config_datacenter_id: Optional[pulumi.Input[builtins.float]] = None,
                                                             config_pop_id: Optional[pulumi.Input[builtins.float]] = None,
                                                             service_name: Optional[pulumi.Input[builtins.str]] = None,
                                                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetOvhcloudConnectConfigPopDatacenterExtrasResult]:
    """
    Use this data source to retrieve information about an Ovhcloud Connect Datacenter Extra configuration

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    extra_cfgs = ovh.get_ovhcloud_connect_config_pop_datacenter_extras(service_name="XXX",
        config_pop_id="YYY",
        config_datacenter_id="ZZZ")
    ```


    :param builtins.float config_datacenter_id: ID of the Datacenter Configuration
    :param builtins.float config_pop_id: ID of the Pop Configuration
    :param builtins.str service_name: Service name
    """
    __args__ = dict()
    __args__['configDatacenterId'] = config_datacenter_id
    __args__['configPopId'] = config_pop_id
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:index/getOvhcloudConnectConfigPopDatacenterExtras:getOvhcloudConnectConfigPopDatacenterExtras', __args__, opts=opts, typ=GetOvhcloudConnectConfigPopDatacenterExtrasResult)
    return __ret__.apply(lambda __response__: GetOvhcloudConnectConfigPopDatacenterExtrasResult(
        config_datacenter_id=pulumi.get(__response__, 'config_datacenter_id'),
        config_pop_id=pulumi.get(__response__, 'config_pop_id'),
        extra_configs=pulumi.get(__response__, 'extra_configs'),
        id=pulumi.get(__response__, 'id'),
        service_name=pulumi.get(__response__, 'service_name')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DSRecordsArgs', 'DSRecords']

@pulumi.input_type
class DSRecordsArgs:
    def __init__(__self__, *,
                 domain: pulumi.Input[builtins.str],
                 ds_records: pulumi.Input[Sequence[pulumi.Input['DSRecordsDsRecordArgs']]]):
        """
        The set of arguments for constructing a DSRecords resource.
        :param pulumi.Input[builtins.str] domain: Domain name for which to manage DS records
        :param pulumi.Input[Sequence[pulumi.Input['DSRecordsDsRecordArgs']]] ds_records: Details about a DS record
        """
        pulumi.set(__self__, "domain", domain)
        pulumi.set(__self__, "ds_records", ds_records)

    @property
    @pulumi.getter
    def domain(self) -> pulumi.Input[builtins.str]:
        """
        Domain name for which to manage DS records
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter(name="dsRecords")
    def ds_records(self) -> pulumi.Input[Sequence[pulumi.Input['DSRecordsDsRecordArgs']]]:
        """
        Details about a DS record
        """
        return pulumi.get(self, "ds_records")

    @ds_records.setter
    def ds_records(self, value: pulumi.Input[Sequence[pulumi.Input['DSRecordsDsRecordArgs']]]):
        pulumi.set(self, "ds_records", value)


@pulumi.input_type
class _DSRecordsState:
    def __init__(__self__, *,
                 domain: Optional[pulumi.Input[builtins.str]] = None,
                 ds_records: Optional[pulumi.Input[Sequence[pulumi.Input['DSRecordsDsRecordArgs']]]] = None):
        """
        Input properties used for looking up and filtering DSRecords resources.
        :param pulumi.Input[builtins.str] domain: Domain name for which to manage DS records
        :param pulumi.Input[Sequence[pulumi.Input['DSRecordsDsRecordArgs']]] ds_records: Details about a DS record
        """
        if domain is not None:
            pulumi.set(__self__, "domain", domain)
        if ds_records is not None:
            pulumi.set(__self__, "ds_records", ds_records)

    @property
    @pulumi.getter
    def domain(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Domain name for which to manage DS records
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter(name="dsRecords")
    def ds_records(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DSRecordsDsRecordArgs']]]]:
        """
        Details about a DS record
        """
        return pulumi.get(self, "ds_records")

    @ds_records.setter
    def ds_records(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DSRecordsDsRecordArgs']]]]):
        pulumi.set(self, "ds_records", value)


@pulumi.type_token("ovh:Domain/dSRecords:DSRecords")
class DSRecords(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 domain: Optional[pulumi.Input[builtins.str]] = None,
                 ds_records: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DSRecordsDsRecordArgs', 'DSRecordsDsRecordArgsDict']]]]] = None,
                 __props__=None):
        """
        Use this resource to manage a domain's DS records.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        ds_records = ovh.domain.DSRecords("ds_records",
            domain="mydomain.ovh",
            ds_records=[{
                "algorithm": "RSASHA1_NSEC3_SHA1",
                "flags": "KEY_SIGNING_KEY",
                "public_key": "my_base64_encoded_public_key",
                "tag": 12345,
            }])
        ```

        ## Import

        DS records can be imported using their `domain`.

        Using the following configuration:

        terraform

        import {

          to = ovh_domain_ds_records.ds_records

          id = "<domain name>"

        }

        You can then run:

        bash

        $ pulumi preview -generate-config-out=ds_records.tf

        $ pulumi up

        The file `ds_records.tf` will then contain the imported resource's configuration, that can be copied next to the `import` block above. See https://developer.hashicorp.com/terraform/language/import/generating-configuration for more details.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] domain: Domain name for which to manage DS records
        :param pulumi.Input[Sequence[pulumi.Input[Union['DSRecordsDsRecordArgs', 'DSRecordsDsRecordArgsDict']]]] ds_records: Details about a DS record
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DSRecordsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Use this resource to manage a domain's DS records.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        ds_records = ovh.domain.DSRecords("ds_records",
            domain="mydomain.ovh",
            ds_records=[{
                "algorithm": "RSASHA1_NSEC3_SHA1",
                "flags": "KEY_SIGNING_KEY",
                "public_key": "my_base64_encoded_public_key",
                "tag": 12345,
            }])
        ```

        ## Import

        DS records can be imported using their `domain`.

        Using the following configuration:

        terraform

        import {

          to = ovh_domain_ds_records.ds_records

          id = "<domain name>"

        }

        You can then run:

        bash

        $ pulumi preview -generate-config-out=ds_records.tf

        $ pulumi up

        The file `ds_records.tf` will then contain the imported resource's configuration, that can be copied next to the `import` block above. See https://developer.hashicorp.com/terraform/language/import/generating-configuration for more details.

        :param str resource_name: The name of the resource.
        :param DSRecordsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DSRecordsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 domain: Optional[pulumi.Input[builtins.str]] = None,
                 ds_records: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DSRecordsDsRecordArgs', 'DSRecordsDsRecordArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DSRecordsArgs.__new__(DSRecordsArgs)

            if domain is None and not opts.urn:
                raise TypeError("Missing required property 'domain'")
            __props__.__dict__["domain"] = domain
            if ds_records is None and not opts.urn:
                raise TypeError("Missing required property 'ds_records'")
            __props__.__dict__["ds_records"] = ds_records
        super(DSRecords, __self__).__init__(
            'ovh:Domain/dSRecords:DSRecords',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            domain: Optional[pulumi.Input[builtins.str]] = None,
            ds_records: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DSRecordsDsRecordArgs', 'DSRecordsDsRecordArgsDict']]]]] = None) -> 'DSRecords':
        """
        Get an existing DSRecords resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] domain: Domain name for which to manage DS records
        :param pulumi.Input[Sequence[pulumi.Input[Union['DSRecordsDsRecordArgs', 'DSRecordsDsRecordArgsDict']]]] ds_records: Details about a DS record
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DSRecordsState.__new__(_DSRecordsState)

        __props__.__dict__["domain"] = domain
        __props__.__dict__["ds_records"] = ds_records
        return DSRecords(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def domain(self) -> pulumi.Output[builtins.str]:
        """
        Domain name for which to manage DS records
        """
        return pulumi.get(self, "domain")

    @property
    @pulumi.getter(name="dsRecords")
    def ds_records(self) -> pulumi.Output[Sequence['outputs.DSRecordsDsRecord']]:
        """
        Details about a DS record
        """
        return pulumi.get(self, "ds_records")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'LogsInputConfigurationArgs',
    'LogsInputConfigurationArgsDict',
    'LogsInputConfigurationFlowggerArgs',
    'LogsInputConfigurationFlowggerArgsDict',
    'LogsInputConfigurationLogstashArgs',
    'LogsInputConfigurationLogstashArgsDict',
]

MYPY = False

if not MYPY:
    class LogsInputConfigurationArgsDict(TypedDict):
        flowgger: NotRequired[pulumi.Input['LogsInputConfigurationFlowggerArgsDict']]
        """
        Flowgger configuration
        """
        logstash: NotRequired[pulumi.Input['LogsInputConfigurationLogstashArgsDict']]
        """
        Logstash configuration
        """
elif False:
    LogsInputConfigurationArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class LogsInputConfigurationArgs:
    def __init__(__self__, *,
                 flowgger: Optional[pulumi.Input['LogsInputConfigurationFlowggerArgs']] = None,
                 logstash: Optional[pulumi.Input['LogsInputConfigurationLogstashArgs']] = None):
        """
        :param pulumi.Input['LogsInputConfigurationFlowggerArgs'] flowgger: Flowgger configuration
        :param pulumi.Input['LogsInputConfigurationLogstashArgs'] logstash: Logstash configuration
        """
        if flowgger is not None:
            pulumi.set(__self__, "flowgger", flowgger)
        if logstash is not None:
            pulumi.set(__self__, "logstash", logstash)

    @property
    @pulumi.getter
    def flowgger(self) -> Optional[pulumi.Input['LogsInputConfigurationFlowggerArgs']]:
        """
        Flowgger configuration
        """
        return pulumi.get(self, "flowgger")

    @flowgger.setter
    def flowgger(self, value: Optional[pulumi.Input['LogsInputConfigurationFlowggerArgs']]):
        pulumi.set(self, "flowgger", value)

    @property
    @pulumi.getter
    def logstash(self) -> Optional[pulumi.Input['LogsInputConfigurationLogstashArgs']]:
        """
        Logstash configuration
        """
        return pulumi.get(self, "logstash")

    @logstash.setter
    def logstash(self, value: Optional[pulumi.Input['LogsInputConfigurationLogstashArgs']]):
        pulumi.set(self, "logstash", value)


if not MYPY:
    class LogsInputConfigurationFlowggerArgsDict(TypedDict):
        log_format: pulumi.Input[builtins.str]
        """
        Type of format to decode. One of "RFC5424", "LTSV", "GELF", "CAPNP"
        """
        log_framing: pulumi.Input[builtins.str]
        """
        Indicates how messages are delimited. One of "LINE", "NUL", "SYSLEN", "CAPNP"
        """
elif False:
    LogsInputConfigurationFlowggerArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class LogsInputConfigurationFlowggerArgs:
    def __init__(__self__, *,
                 log_format: pulumi.Input[builtins.str],
                 log_framing: pulumi.Input[builtins.str]):
        """
        :param pulumi.Input[builtins.str] log_format: Type of format to decode. One of "RFC5424", "LTSV", "GELF", "CAPNP"
        :param pulumi.Input[builtins.str] log_framing: Indicates how messages are delimited. One of "LINE", "NUL", "SYSLEN", "CAPNP"
        """
        pulumi.set(__self__, "log_format", log_format)
        pulumi.set(__self__, "log_framing", log_framing)

    @property
    @pulumi.getter(name="logFormat")
    def log_format(self) -> pulumi.Input[builtins.str]:
        """
        Type of format to decode. One of "RFC5424", "LTSV", "GELF", "CAPNP"
        """
        return pulumi.get(self, "log_format")

    @log_format.setter
    def log_format(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "log_format", value)

    @property
    @pulumi.getter(name="logFraming")
    def log_framing(self) -> pulumi.Input[builtins.str]:
        """
        Indicates how messages are delimited. One of "LINE", "NUL", "SYSLEN", "CAPNP"
        """
        return pulumi.get(self, "log_framing")

    @log_framing.setter
    def log_framing(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "log_framing", value)


if not MYPY:
    class LogsInputConfigurationLogstashArgsDict(TypedDict):
        input_section: pulumi.Input[builtins.str]
        """
        The filter section of logstash.conf
        """
        filter_section: NotRequired[pulumi.Input[builtins.str]]
        """
        The filter section of logstash.conf
        """
        pattern_section: NotRequired[pulumi.Input[builtins.str]]
        """
        The list of customs Grok patterns
        """
elif False:
    LogsInputConfigurationLogstashArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class LogsInputConfigurationLogstashArgs:
    def __init__(__self__, *,
                 input_section: pulumi.Input[builtins.str],
                 filter_section: Optional[pulumi.Input[builtins.str]] = None,
                 pattern_section: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] input_section: The filter section of logstash.conf
        :param pulumi.Input[builtins.str] filter_section: The filter section of logstash.conf
        :param pulumi.Input[builtins.str] pattern_section: The list of customs Grok patterns
        """
        pulumi.set(__self__, "input_section", input_section)
        if filter_section is not None:
            pulumi.set(__self__, "filter_section", filter_section)
        if pattern_section is not None:
            pulumi.set(__self__, "pattern_section", pattern_section)

    @property
    @pulumi.getter(name="inputSection")
    def input_section(self) -> pulumi.Input[builtins.str]:
        """
        The filter section of logstash.conf
        """
        return pulumi.get(self, "input_section")

    @input_section.setter
    def input_section(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "input_section", value)

    @property
    @pulumi.getter(name="filterSection")
    def filter_section(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The filter section of logstash.conf
        """
        return pulumi.get(self, "filter_section")

    @filter_section.setter
    def filter_section(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "filter_section", value)

    @property
    @pulumi.getter(name="patternSection")
    def pattern_section(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The list of customs Grok patterns
        """
        return pulumi.get(self, "pattern_section")

    @pattern_section.setter
    def pattern_section(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "pattern_section", value)





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'ConnectsResult',
    'AwaitableConnectsResult',
    'connects',
    'connects_output',
]

@pulumi.output_type
class ConnectsResult:
    """
    A collection of values returned by Connects.
    """
    def __init__(__self__, id=None, occs=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if occs and not isinstance(occs, list):
            raise TypeError("Expected argument 'occs' to be a list")
        pulumi.set(__self__, "occs", occs)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def occs(self) -> Sequence['outputs.ConnectsOccResult']:
        return pulumi.get(self, "occs")


class AwaitableConnectsResult(ConnectsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return ConnectsResult(
            id=self.id,
            occs=self.occs)


def connects(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableConnectsResult:
    """
    Get the details of your Ovhcloud Connect products.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    occs = ovh.OVHcloud.connect()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:OVHcloud/connects:Connects', __args__, opts=opts, typ=ConnectsResult).value

    return AwaitableConnectsResult(
        id=pulumi.get(__ret__, 'id'),
        occs=pulumi.get(__ret__, 'occs'))
def connects_output(opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[ConnectsResult]:
    """
    Get the details of your Ovhcloud Connect products.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    occs = ovh.OVHcloud.connect()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:OVHcloud/connects:Connects', __args__, opts=opts, typ=ConnectsResult)
    return __ret__.apply(lambda __response__: ConnectsResult(
        id=pulumi.get(__response__, 'id'),
        occs=pulumi.get(__response__, 'occs')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetCloudProjectFlavorCapabilityResult',
    'GetCloudProjectFlavorPlanCodesResult',
    'GetCloudProjectRancherCapabilitiesPlanPlanResult',
    'GetCloudProjectRancherCapabilitiesVersionVersionResult',
    'GetCloudProjectSshKeysSshKeyResult',
    'GetInstallationTemplateInputResult',
    'GetInstallationTemplateLicenseResult',
    'GetInstallationTemplateLicenseOResult',
    'GetInstallationTemplateLicenseUsageResult',
    'GetInstallationTemplateProjectResult',
    'GetInstallationTemplateProjectOResult',
    'GetInstallationTemplateProjectUsageResult',
    'GetOvhcloudConnectConfigPopDatacenterExtrasExtraConfigResult',
    'GetOvhcloudConnectConfigPopDatacentersDatacenterConfigResult',
    'GetOvhcloudConnectConfigPopsPopConfigResult',
    'GetOvhcloudConnectDatacentersDatacenterResult',
    'GetServerVniResult',
]

@pulumi.output_type
class GetCloudProjectFlavorCapabilityResult(dict):
    def __init__(__self__, *,
                 enabled: builtins.bool,
                 name: builtins.str):
        """
        :param builtins.bool enabled: Is the capability enabled
        :param builtins.str name: Name of the capability
        """
        pulumi.set(__self__, "enabled", enabled)
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def enabled(self) -> builtins.bool:
        """
        Is the capability enabled
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        Name of the capability
        """
        return pulumi.get(self, "name")


@pulumi.output_type
class GetCloudProjectFlavorPlanCodesResult(dict):
    def __init__(__self__, *,
                 hourly: builtins.str,
                 monthly: builtins.str):
        """
        :param builtins.str hourly: Plan code to order hourly instance
        :param builtins.str monthly: Plan code to order monthly instance
        """
        pulumi.set(__self__, "hourly", hourly)
        pulumi.set(__self__, "monthly", monthly)

    @property
    @pulumi.getter
    def hourly(self) -> builtins.str:
        """
        Plan code to order hourly instance
        """
        return pulumi.get(self, "hourly")

    @property
    @pulumi.getter
    def monthly(self) -> builtins.str:
        """
        Plan code to order monthly instance
        """
        return pulumi.get(self, "monthly")


@pulumi.output_type
class GetCloudProjectRancherCapabilitiesPlanPlanResult(dict):
    def __init__(__self__, *,
                 cause: builtins.str,
                 message: builtins.str,
                 name: builtins.str,
                 status: builtins.str):
        """
        :param builtins.str cause: Cause for an unavailability
        :param builtins.str message: Human-readable description of the unavailability cause
        :param builtins.str name: Name of the plan
        :param builtins.str status: Status of the plan
        """
        pulumi.set(__self__, "cause", cause)
        pulumi.set(__self__, "message", message)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def cause(self) -> builtins.str:
        """
        Cause for an unavailability
        """
        return pulumi.get(self, "cause")

    @property
    @pulumi.getter
    def message(self) -> builtins.str:
        """
        Human-readable description of the unavailability cause
        """
        return pulumi.get(self, "message")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        Name of the plan
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        Status of the plan
        """
        return pulumi.get(self, "status")


@pulumi.output_type
class GetCloudProjectRancherCapabilitiesVersionVersionResult(dict):
    def __init__(__self__, *,
                 cause: builtins.str,
                 changelog_url: builtins.str,
                 message: builtins.str,
                 name: builtins.str,
                 status: builtins.str):
        """
        :param builtins.str cause: Cause for an unavailability
        :param builtins.str changelog_url: Changelog URL of the version
        :param builtins.str message: Human-readable description of the unavailability cause
        :param builtins.str name: Name of the version
        :param builtins.str status: Status of the version
        """
        pulumi.set(__self__, "cause", cause)
        pulumi.set(__self__, "changelog_url", changelog_url)
        pulumi.set(__self__, "message", message)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def cause(self) -> builtins.str:
        """
        Cause for an unavailability
        """
        return pulumi.get(self, "cause")

    @property
    @pulumi.getter(name="changelogUrl")
    def changelog_url(self) -> builtins.str:
        """
        Changelog URL of the version
        """
        return pulumi.get(self, "changelog_url")

    @property
    @pulumi.getter
    def message(self) -> builtins.str:
        """
        Human-readable description of the unavailability cause
        """
        return pulumi.get(self, "message")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        Name of the version
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        Status of the version
        """
        return pulumi.get(self, "status")


@pulumi.output_type
class GetCloudProjectSshKeysSshKeyResult(dict):
    def __init__(__self__, *,
                 id: builtins.str,
                 name: builtins.str,
                 public_key: builtins.str,
                 regions: Sequence[builtins.str]):
        """
        :param builtins.str id: SSH key ID
        :param builtins.str name: SSH key name
        :param builtins.str public_key: SSH public key
        :param Sequence[builtins.str] regions: SSH key regions
        """
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "public_key", public_key)
        pulumi.set(__self__, "regions", regions)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        SSH key ID
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        SSH key name
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="publicKey")
    def public_key(self) -> builtins.str:
        """
        SSH public key
        """
        return pulumi.get(self, "public_key")

    @property
    @pulumi.getter
    def regions(self) -> Sequence[builtins.str]:
        """
        SSH key regions
        """
        return pulumi.get(self, "regions")


@pulumi.output_type
class GetInstallationTemplateInputResult(dict):
    def __init__(__self__, *,
                 default: builtins.str,
                 description: builtins.str,
                 enums: Sequence[builtins.str],
                 mandatory: builtins.bool,
                 name: builtins.str,
                 type: builtins.str):
        """
        :param builtins.str description: Information about this template.
        """
        pulumi.set(__self__, "default", default)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "enums", enums)
        pulumi.set(__self__, "mandatory", mandatory)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def default(self) -> builtins.str:
        return pulumi.get(self, "default")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Information about this template.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def enums(self) -> Sequence[builtins.str]:
        return pulumi.get(self, "enums")

    @property
    @pulumi.getter
    def mandatory(self) -> builtins.bool:
        return pulumi.get(self, "mandatory")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        return pulumi.get(self, "type")


@pulumi.output_type
class GetInstallationTemplateLicenseResult(dict):
    def __init__(__self__, *,
                 os: Sequence['outputs.GetInstallationTemplateLicenseOResult'],
                 usages: Sequence['outputs.GetInstallationTemplateLicenseUsageResult']):
        pulumi.set(__self__, "os", os)
        pulumi.set(__self__, "usages", usages)

    @property
    @pulumi.getter
    def os(self) -> Sequence['outputs.GetInstallationTemplateLicenseOResult']:
        return pulumi.get(self, "os")

    @property
    @pulumi.getter
    def usages(self) -> Sequence['outputs.GetInstallationTemplateLicenseUsageResult']:
        return pulumi.get(self, "usages")


@pulumi.output_type
class GetInstallationTemplateLicenseOResult(dict):
    def __init__(__self__, *,
                 names: Sequence[builtins.str],
                 url: builtins.str):
        pulumi.set(__self__, "names", names)
        pulumi.set(__self__, "url", url)

    @property
    @pulumi.getter
    def names(self) -> Sequence[builtins.str]:
        return pulumi.get(self, "names")

    @property
    @pulumi.getter
    def url(self) -> builtins.str:
        return pulumi.get(self, "url")


@pulumi.output_type
class GetInstallationTemplateLicenseUsageResult(dict):
    def __init__(__self__, *,
                 names: Sequence[builtins.str],
                 url: builtins.str):
        pulumi.set(__self__, "names", names)
        pulumi.set(__self__, "url", url)

    @property
    @pulumi.getter
    def names(self) -> Sequence[builtins.str]:
        return pulumi.get(self, "names")

    @property
    @pulumi.getter
    def url(self) -> builtins.str:
        return pulumi.get(self, "url")


@pulumi.output_type
class GetInstallationTemplateProjectResult(dict):
    def __init__(__self__, *,
                 os: Sequence['outputs.GetInstallationTemplateProjectOResult'],
                 usages: Sequence['outputs.GetInstallationTemplateProjectUsageResult']):
        """
        :param Sequence['GetInstallationTemplateProjectOArgs'] os: OS template project OS details
        """
        pulumi.set(__self__, "os", os)
        pulumi.set(__self__, "usages", usages)

    @property
    @pulumi.getter
    def os(self) -> Sequence['outputs.GetInstallationTemplateProjectOResult']:
        """
        OS template project OS details
        """
        return pulumi.get(self, "os")

    @property
    @pulumi.getter
    def usages(self) -> Sequence['outputs.GetInstallationTemplateProjectUsageResult']:
        return pulumi.get(self, "usages")


@pulumi.output_type
class GetInstallationTemplateProjectOResult(dict):
    def __init__(__self__, *,
                 governances: Sequence[builtins.str],
                 name: builtins.str,
                 release_notes: builtins.str,
                 url: builtins.str,
                 version: builtins.str):
        """
        :param Sequence[builtins.str] governances: OS template project item governance
        :param builtins.str name: OS template project item name
        :param builtins.str release_notes: OS template project item release notes
        :param builtins.str url: OS template project item url
        :param builtins.str version: OS template project item version
        """
        pulumi.set(__self__, "governances", governances)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "release_notes", release_notes)
        pulumi.set(__self__, "url", url)
        pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter
    def governances(self) -> Sequence[builtins.str]:
        """
        OS template project item governance
        """
        return pulumi.get(self, "governances")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        OS template project item name
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="releaseNotes")
    def release_notes(self) -> builtins.str:
        """
        OS template project item release notes
        """
        return pulumi.get(self, "release_notes")

    @property
    @pulumi.getter
    def url(self) -> builtins.str:
        """
        OS template project item url
        """
        return pulumi.get(self, "url")

    @property
    @pulumi.getter
    def version(self) -> builtins.str:
        """
        OS template project item version
        """
        return pulumi.get(self, "version")


@pulumi.output_type
class GetInstallationTemplateProjectUsageResult(dict):
    def __init__(__self__, *,
                 governances: Sequence[builtins.str],
                 name: builtins.str,
                 release_notes: builtins.str,
                 url: builtins.str,
                 version: builtins.str):
        """
        :param Sequence[builtins.str] governances: OS template project item governance
        :param builtins.str name: OS template project item name
        :param builtins.str release_notes: OS template project item release notes
        :param builtins.str url: OS template project item url
        :param builtins.str version: OS template project item version
        """
        pulumi.set(__self__, "governances", governances)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "release_notes", release_notes)
        pulumi.set(__self__, "url", url)
        pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter
    def governances(self) -> Sequence[builtins.str]:
        """
        OS template project item governance
        """
        return pulumi.get(self, "governances")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        OS template project item name
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="releaseNotes")
    def release_notes(self) -> builtins.str:
        """
        OS template project item release notes
        """
        return pulumi.get(self, "release_notes")

    @property
    @pulumi.getter
    def url(self) -> builtins.str:
        """
        OS template project item url
        """
        return pulumi.get(self, "url")

    @property
    @pulumi.getter
    def version(self) -> builtins.str:
        """
        OS template project item version
        """
        return pulumi.get(self, "version")


@pulumi.output_type
class GetOvhcloudConnectConfigPopDatacenterExtrasExtraConfigResult(dict):
    def __init__(__self__, *,
                 bgp_neighbor_area: builtins.float,
                 bgp_neighbor_ip: builtins.str,
                 id: builtins.float,
                 next_hop: builtins.str,
                 status: builtins.str,
                 subnet: builtins.str,
                 type: builtins.str):
        """
        :param builtins.float bgp_neighbor_area: BGP AS number
        :param builtins.str bgp_neighbor_ip: Router IP for BGP
        :param builtins.float id: ID of the extra configuration
        :param builtins.str next_hop: Static route next hop
        :param builtins.str status: Status of the pop configuration
        :param builtins.str subnet: Static route ip
        :param builtins.str type: Type of the configuration
        """
        pulumi.set(__self__, "bgp_neighbor_area", bgp_neighbor_area)
        pulumi.set(__self__, "bgp_neighbor_ip", bgp_neighbor_ip)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "next_hop", next_hop)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "subnet", subnet)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="bgpNeighborArea")
    def bgp_neighbor_area(self) -> builtins.float:
        """
        BGP AS number
        """
        return pulumi.get(self, "bgp_neighbor_area")

    @property
    @pulumi.getter(name="bgpNeighborIp")
    def bgp_neighbor_ip(self) -> builtins.str:
        """
        Router IP for BGP
        """
        return pulumi.get(self, "bgp_neighbor_ip")

    @property
    @pulumi.getter
    def id(self) -> builtins.float:
        """
        ID of the extra configuration
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="nextHop")
    def next_hop(self) -> builtins.str:
        """
        Static route next hop
        """
        return pulumi.get(self, "next_hop")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        Status of the pop configuration
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def subnet(self) -> builtins.str:
        """
        Static route ip
        """
        return pulumi.get(self, "subnet")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        """
        Type of the configuration
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class GetOvhcloudConnectConfigPopDatacentersDatacenterConfigResult(dict):
    def __init__(__self__, *,
                 datacenter_id: builtins.float,
                 id: builtins.float,
                 ovh_bgp_area: builtins.float,
                 status: builtins.str,
                 subnet: builtins.str):
        """
        :param builtins.float datacenter_id: Datacenter ID
        :param builtins.float id: ID of the Datacenter configuration
        :param builtins.float ovh_bgp_area: OVH Private AS
        :param builtins.str status: Status of the pop configuration
        :param builtins.str subnet: Subnet should be a /28 min
        """
        pulumi.set(__self__, "datacenter_id", datacenter_id)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "ovh_bgp_area", ovh_bgp_area)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "subnet", subnet)

    @property
    @pulumi.getter(name="datacenterId")
    def datacenter_id(self) -> builtins.float:
        """
        Datacenter ID
        """
        return pulumi.get(self, "datacenter_id")

    @property
    @pulumi.getter
    def id(self) -> builtins.float:
        """
        ID of the Datacenter configuration
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="ovhBgpArea")
    def ovh_bgp_area(self) -> builtins.float:
        """
        OVH Private AS
        """
        return pulumi.get(self, "ovh_bgp_area")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        Status of the pop configuration
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def subnet(self) -> builtins.str:
        """
        Subnet should be a /28 min
        """
        return pulumi.get(self, "subnet")


@pulumi.output_type
class GetOvhcloudConnectConfigPopsPopConfigResult(dict):
    def __init__(__self__, *,
                 customer_bgp_area: builtins.float,
                 id: builtins.float,
                 interface_id: builtins.float,
                 ovh_bgp_area: builtins.float,
                 status: builtins.str,
                 subnet: builtins.str,
                 type: builtins.str):
        """
        :param builtins.float customer_bgp_area: Customer Private AS
        :param builtins.float id: ID of the Pop Configuration
        :param builtins.float interface_id: ID of the interface
        :param builtins.float ovh_bgp_area: OVH Private AS
        :param builtins.str status: Status of the pop configuration
        :param builtins.str subnet: Subnet should be a /30, first IP for OVH, second IP for customer
        :param builtins.str type: Type of the pop configuration
        """
        pulumi.set(__self__, "customer_bgp_area", customer_bgp_area)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "interface_id", interface_id)
        pulumi.set(__self__, "ovh_bgp_area", ovh_bgp_area)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "subnet", subnet)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="customerBgpArea")
    def customer_bgp_area(self) -> builtins.float:
        """
        Customer Private AS
        """
        return pulumi.get(self, "customer_bgp_area")

    @property
    @pulumi.getter
    def id(self) -> builtins.float:
        """
        ID of the Pop Configuration
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="interfaceId")
    def interface_id(self) -> builtins.float:
        """
        ID of the interface
        """
        return pulumi.get(self, "interface_id")

    @property
    @pulumi.getter(name="ovhBgpArea")
    def ovh_bgp_area(self) -> builtins.float:
        """
        OVH Private AS
        """
        return pulumi.get(self, "ovh_bgp_area")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        Status of the pop configuration
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def subnet(self) -> builtins.str:
        """
        Subnet should be a /30, first IP for OVH, second IP for customer
        """
        return pulumi.get(self, "subnet")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        """
        Type of the pop configuration
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class GetOvhcloudConnectDatacentersDatacenterResult(dict):
    def __init__(__self__, *,
                 available: builtins.bool,
                 id: builtins.float,
                 name: builtins.str,
                 region: builtins.str,
                 region_type: builtins.str):
        """
        :param builtins.bool available: Get availability to add new configuration on it
        :param builtins.float id: Id
        :param builtins.str name: name of the datacenter
        :param builtins.str region: region of the datacenter
        :param builtins.str region_type: region type of the datacenter
        """
        pulumi.set(__self__, "available", available)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "region", region)
        pulumi.set(__self__, "region_type", region_type)

    @property
    @pulumi.getter
    def available(self) -> builtins.bool:
        """
        Get availability to add new configuration on it
        """
        return pulumi.get(self, "available")

    @property
    @pulumi.getter
    def id(self) -> builtins.float:
        """
        Id
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        name of the datacenter
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def region(self) -> builtins.str:
        """
        region of the datacenter
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="regionType")
    def region_type(self) -> builtins.str:
        """
        region type of the datacenter
        """
        return pulumi.get(self, "region_type")


@pulumi.output_type
class GetServerVniResult(dict):
    def __init__(__self__, *,
                 enabled: builtins.bool,
                 mode: builtins.str,
                 name: builtins.str,
                 nics: Sequence[builtins.str],
                 server_name: builtins.str,
                 uuid: builtins.str,
                 vrack: builtins.str):
        """
        :param builtins.bool enabled: VirtualNetworkInterface activation state
        :param builtins.str mode: VirtualNetworkInterface mode (public,vrack,vrack_aggregation)
        :param builtins.str name: User defined VirtualNetworkInterface name
        :param Sequence[builtins.str] nics: NetworkInterfaceControllers bound to this VirtualNetworkInterface
        :param builtins.str server_name: Server bound to this VirtualNetworkInterface
        :param builtins.str uuid: VirtualNetworkInterface unique id
        :param builtins.str vrack: vRack name
        """
        pulumi.set(__self__, "enabled", enabled)
        pulumi.set(__self__, "mode", mode)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "nics", nics)
        pulumi.set(__self__, "server_name", server_name)
        pulumi.set(__self__, "uuid", uuid)
        pulumi.set(__self__, "vrack", vrack)

    @property
    @pulumi.getter
    def enabled(self) -> builtins.bool:
        """
        VirtualNetworkInterface activation state
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter
    def mode(self) -> builtins.str:
        """
        VirtualNetworkInterface mode (public,vrack,vrack_aggregation)
        """
        return pulumi.get(self, "mode")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        User defined VirtualNetworkInterface name
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def nics(self) -> Sequence[builtins.str]:
        """
        NetworkInterfaceControllers bound to this VirtualNetworkInterface
        """
        return pulumi.get(self, "nics")

    @property
    @pulumi.getter(name="serverName")
    def server_name(self) -> builtins.str:
        """
        Server bound to this VirtualNetworkInterface
        """
        return pulumi.get(self, "server_name")

    @property
    @pulumi.getter
    def uuid(self) -> builtins.str:
        """
        VirtualNetworkInterface unique id
        """
        return pulumi.get(self, "uuid")

    @property
    @pulumi.getter
    def vrack(self) -> builtins.str:
        """
        vRack name
        """
        return pulumi.get(self, "vrack")





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetUserS3PolicyResult',
    'AwaitableGetUserS3PolicyResult',
    'get_user_s3_policy',
    'get_user_s3_policy_output',
]

@pulumi.output_type
class GetUserS3PolicyResult:
    """
    A collection of values returned by getUserS3Policy.
    """
    def __init__(__self__, id=None, policy=None, service_name=None, user_id=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if policy and not isinstance(policy, str):
            raise TypeError("Expected argument 'policy' to be a str")
        pulumi.set(__self__, "policy", policy)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if user_id and not isinstance(user_id, str):
            raise TypeError("Expected argument 'user_id' to be a str")
        pulumi.set(__self__, "user_id", user_id)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def policy(self) -> builtins.str:
        """
        (Required) The policy document. This is a JSON formatted string.
        """
        return pulumi.get(self, "policy")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> builtins.str:
        return pulumi.get(self, "user_id")


class AwaitableGetUserS3PolicyResult(GetUserS3PolicyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetUserS3PolicyResult(
            id=self.id,
            policy=self.policy,
            service_name=self.service_name,
            user_id=self.user_id)


def get_user_s3_policy(service_name: Optional[builtins.str] = None,
                       user_id: Optional[builtins.str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetUserS3PolicyResult:
    """
    Get the S3 Policy of a public cloud project user. The policy can be set by using the `CloudProject.S3Policy` resource.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    project_users = ovh.CloudProject.get_users(service_name="XXX")
    # Get the user ID of a previously created user with the description "S3-User"
    users = [user.user_id for user in project_users.users if user.description == "S3-User"]
    s3_user_id = users[0]
    policy = ovh.CloudProject.get_user_s3_policy(service_name=project_users.service_name,
        user_id=s3_user_id)
    ```


    :param builtins.str service_name: The ID of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    :param builtins.str user_id: The ID of a public cloud project's user.
    """
    __args__ = dict()
    __args__['serviceName'] = service_name
    __args__['userId'] = user_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:CloudProject/getUserS3Policy:getUserS3Policy', __args__, opts=opts, typ=GetUserS3PolicyResult).value

    return AwaitableGetUserS3PolicyResult(
        id=pulumi.get(__ret__, 'id'),
        policy=pulumi.get(__ret__, 'policy'),
        service_name=pulumi.get(__ret__, 'service_name'),
        user_id=pulumi.get(__ret__, 'user_id'))
def get_user_s3_policy_output(service_name: Optional[pulumi.Input[builtins.str]] = None,
                              user_id: Optional[pulumi.Input[builtins.str]] = None,
                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetUserS3PolicyResult]:
    """
    Get the S3 Policy of a public cloud project user. The policy can be set by using the `CloudProject.S3Policy` resource.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    project_users = ovh.CloudProject.get_users(service_name="XXX")
    # Get the user ID of a previously created user with the description "S3-User"
    users = [user.user_id for user in project_users.users if user.description == "S3-User"]
    s3_user_id = users[0]
    policy = ovh.CloudProject.get_user_s3_policy(service_name=project_users.service_name,
        user_id=s3_user_id)
    ```


    :param builtins.str service_name: The ID of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    :param builtins.str user_id: The ID of a public cloud project's user.
    """
    __args__ = dict()
    __args__['serviceName'] = service_name
    __args__['userId'] = user_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:CloudProject/getUserS3Policy:getUserS3Policy', __args__, opts=opts, typ=GetUserS3PolicyResult)
    return __ret__.apply(lambda __response__: GetUserS3PolicyResult(
        id=pulumi.get(__response__, 'id'),
        policy=pulumi.get(__response__, 'policy'),
        service_name=pulumi.get(__response__, 'service_name'),
        user_id=pulumi.get(__response__, 'user_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['LogsClusterArgs', 'LogsCluster']

@pulumi.input_type
class LogsClusterArgs:
    def __init__(__self__, *,
                 service_name: pulumi.Input[builtins.str],
                 archive_allowed_networks: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 direct_input_allowed_networks: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 query_allowed_networks: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        The set of arguments for constructing a LogsCluster resource.
        :param pulumi.Input[builtins.str] service_name: The service name
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] archive_allowed_networks: List of IP blocks
        :param pulumi.Input[builtins.str] cluster_id: Cluster ID. If not provided, the default cluster_id is used
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] direct_input_allowed_networks: List of IP blocks
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] query_allowed_networks: List of IP blocks
        """
        pulumi.set(__self__, "service_name", service_name)
        if archive_allowed_networks is not None:
            pulumi.set(__self__, "archive_allowed_networks", archive_allowed_networks)
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if direct_input_allowed_networks is not None:
            pulumi.set(__self__, "direct_input_allowed_networks", direct_input_allowed_networks)
        if query_allowed_networks is not None:
            pulumi.set(__self__, "query_allowed_networks", query_allowed_networks)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[builtins.str]:
        """
        The service name
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter(name="archiveAllowedNetworks")
    def archive_allowed_networks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        List of IP blocks
        """
        return pulumi.get(self, "archive_allowed_networks")

    @archive_allowed_networks.setter
    def archive_allowed_networks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "archive_allowed_networks", value)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Cluster ID. If not provided, the default cluster_id is used
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter(name="directInputAllowedNetworks")
    def direct_input_allowed_networks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        List of IP blocks
        """
        return pulumi.get(self, "direct_input_allowed_networks")

    @direct_input_allowed_networks.setter
    def direct_input_allowed_networks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "direct_input_allowed_networks", value)

    @property
    @pulumi.getter(name="queryAllowedNetworks")
    def query_allowed_networks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        List of IP blocks
        """
        return pulumi.get(self, "query_allowed_networks")

    @query_allowed_networks.setter
    def query_allowed_networks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "query_allowed_networks", value)


@pulumi.input_type
class _LogsClusterState:
    def __init__(__self__, *,
                 archive_allowed_networks: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 cluster_type: Optional[pulumi.Input[builtins.str]] = None,
                 dedicated_input_pem: Optional[pulumi.Input[builtins.str]] = None,
                 direct_input_allowed_networks: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 direct_input_pem: Optional[pulumi.Input[builtins.str]] = None,
                 hostname: Optional[pulumi.Input[builtins.str]] = None,
                 initial_archive_allowed_networks: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 initial_direct_input_allowed_networks: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 initial_query_allowed_networks: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 is_default: Optional[pulumi.Input[builtins.bool]] = None,
                 is_unlocked: Optional[pulumi.Input[builtins.bool]] = None,
                 query_allowed_networks: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering LogsCluster resources.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] archive_allowed_networks: List of IP blocks
        :param pulumi.Input[builtins.str] cluster_id: Cluster ID. If not provided, the default cluster_id is used
        :param pulumi.Input[builtins.str] cluster_type: type of cluster (DEDICATED, PRO or TRIAL)
        :param pulumi.Input[builtins.str] dedicated_input_pem: PEM for dedicated inputs
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] direct_input_allowed_networks: List of IP blocks
        :param pulumi.Input[builtins.str] direct_input_pem: PEM for direct inputs
        :param pulumi.Input[builtins.str] hostname: cluster hostname hosting tenant
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] initial_archive_allowed_networks: Initial allowed networks for ARCHIVE flow type
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] initial_direct_input_allowed_networks: Initial allowed networks for DIRECT_INPUT flow type
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] initial_query_allowed_networks: Initial allowed networks for QUERY flow type
        :param pulumi.Input[builtins.bool] is_default: true if all content generated by given service will be placed on this cluster
        :param pulumi.Input[builtins.bool] is_unlocked: true if given service can perform advanced operations on cluster
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] query_allowed_networks: List of IP blocks
        :param pulumi.Input[builtins.str] region: datacenter localization
        :param pulumi.Input[builtins.str] service_name: The service name
        """
        if archive_allowed_networks is not None:
            pulumi.set(__self__, "archive_allowed_networks", archive_allowed_networks)
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if cluster_type is not None:
            pulumi.set(__self__, "cluster_type", cluster_type)
        if dedicated_input_pem is not None:
            pulumi.set(__self__, "dedicated_input_pem", dedicated_input_pem)
        if direct_input_allowed_networks is not None:
            pulumi.set(__self__, "direct_input_allowed_networks", direct_input_allowed_networks)
        if direct_input_pem is not None:
            pulumi.set(__self__, "direct_input_pem", direct_input_pem)
        if hostname is not None:
            pulumi.set(__self__, "hostname", hostname)
        if initial_archive_allowed_networks is not None:
            pulumi.set(__self__, "initial_archive_allowed_networks", initial_archive_allowed_networks)
        if initial_direct_input_allowed_networks is not None:
            pulumi.set(__self__, "initial_direct_input_allowed_networks", initial_direct_input_allowed_networks)
        if initial_query_allowed_networks is not None:
            pulumi.set(__self__, "initial_query_allowed_networks", initial_query_allowed_networks)
        if is_default is not None:
            pulumi.set(__self__, "is_default", is_default)
        if is_unlocked is not None:
            pulumi.set(__self__, "is_unlocked", is_unlocked)
        if query_allowed_networks is not None:
            pulumi.set(__self__, "query_allowed_networks", query_allowed_networks)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)

    @property
    @pulumi.getter(name="archiveAllowedNetworks")
    def archive_allowed_networks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        List of IP blocks
        """
        return pulumi.get(self, "archive_allowed_networks")

    @archive_allowed_networks.setter
    def archive_allowed_networks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "archive_allowed_networks", value)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Cluster ID. If not provided, the default cluster_id is used
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter(name="clusterType")
    def cluster_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        type of cluster (DEDICATED, PRO or TRIAL)
        """
        return pulumi.get(self, "cluster_type")

    @cluster_type.setter
    def cluster_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cluster_type", value)

    @property
    @pulumi.getter(name="dedicatedInputPem")
    def dedicated_input_pem(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        PEM for dedicated inputs
        """
        return pulumi.get(self, "dedicated_input_pem")

    @dedicated_input_pem.setter
    def dedicated_input_pem(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "dedicated_input_pem", value)

    @property
    @pulumi.getter(name="directInputAllowedNetworks")
    def direct_input_allowed_networks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        List of IP blocks
        """
        return pulumi.get(self, "direct_input_allowed_networks")

    @direct_input_allowed_networks.setter
    def direct_input_allowed_networks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "direct_input_allowed_networks", value)

    @property
    @pulumi.getter(name="directInputPem")
    def direct_input_pem(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        PEM for direct inputs
        """
        return pulumi.get(self, "direct_input_pem")

    @direct_input_pem.setter
    def direct_input_pem(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "direct_input_pem", value)

    @property
    @pulumi.getter
    def hostname(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        cluster hostname hosting tenant
        """
        return pulumi.get(self, "hostname")

    @hostname.setter
    def hostname(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "hostname", value)

    @property
    @pulumi.getter(name="initialArchiveAllowedNetworks")
    def initial_archive_allowed_networks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Initial allowed networks for ARCHIVE flow type
        """
        return pulumi.get(self, "initial_archive_allowed_networks")

    @initial_archive_allowed_networks.setter
    def initial_archive_allowed_networks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "initial_archive_allowed_networks", value)

    @property
    @pulumi.getter(name="initialDirectInputAllowedNetworks")
    def initial_direct_input_allowed_networks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Initial allowed networks for DIRECT_INPUT flow type
        """
        return pulumi.get(self, "initial_direct_input_allowed_networks")

    @initial_direct_input_allowed_networks.setter
    def initial_direct_input_allowed_networks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "initial_direct_input_allowed_networks", value)

    @property
    @pulumi.getter(name="initialQueryAllowedNetworks")
    def initial_query_allowed_networks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Initial allowed networks for QUERY flow type
        """
        return pulumi.get(self, "initial_query_allowed_networks")

    @initial_query_allowed_networks.setter
    def initial_query_allowed_networks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "initial_query_allowed_networks", value)

    @property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        true if all content generated by given service will be placed on this cluster
        """
        return pulumi.get(self, "is_default")

    @is_default.setter
    def is_default(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "is_default", value)

    @property
    @pulumi.getter(name="isUnlocked")
    def is_unlocked(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        true if given service can perform advanced operations on cluster
        """
        return pulumi.get(self, "is_unlocked")

    @is_unlocked.setter
    def is_unlocked(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "is_unlocked", value)

    @property
    @pulumi.getter(name="queryAllowedNetworks")
    def query_allowed_networks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        List of IP blocks
        """
        return pulumi.get(self, "query_allowed_networks")

    @query_allowed_networks.setter
    def query_allowed_networks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "query_allowed_networks", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        datacenter localization
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The service name
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)


@pulumi.type_token("ovh:Dbaas/logsCluster:LogsCluster")
class LogsCluster(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 archive_allowed_networks: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 direct_input_allowed_networks: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 query_allowed_networks: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        ldp = ovh.dbaas.LogsCluster("ldp",
            service_name="ldp-xx-xxxxx",
            cluster_id="xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx",
            archive_allowed_networks=["10.0.0.0/16"],
            direct_input_allowed_networks=["10.0.0.0/16"],
            query_allowed_networks=["10.0.0.0/16"])
        ```

        ## Import

        OVHcloud DBaaS Log Data Platform clusters can be imported using the `service_name` and `cluster_id` of the cluster, separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:Dbaas/logsCluster:LogsCluster ldp service_name/cluster_id
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] archive_allowed_networks: List of IP blocks
        :param pulumi.Input[builtins.str] cluster_id: Cluster ID. If not provided, the default cluster_id is used
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] direct_input_allowed_networks: List of IP blocks
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] query_allowed_networks: List of IP blocks
        :param pulumi.Input[builtins.str] service_name: The service name
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: LogsClusterArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        ldp = ovh.dbaas.LogsCluster("ldp",
            service_name="ldp-xx-xxxxx",
            cluster_id="xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx",
            archive_allowed_networks=["10.0.0.0/16"],
            direct_input_allowed_networks=["10.0.0.0/16"],
            query_allowed_networks=["10.0.0.0/16"])
        ```

        ## Import

        OVHcloud DBaaS Log Data Platform clusters can be imported using the `service_name` and `cluster_id` of the cluster, separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:Dbaas/logsCluster:LogsCluster ldp service_name/cluster_id
        ```

        :param str resource_name: The name of the resource.
        :param LogsClusterArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(LogsClusterArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 archive_allowed_networks: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 direct_input_allowed_networks: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 query_allowed_networks: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = LogsClusterArgs.__new__(LogsClusterArgs)

            __props__.__dict__["archive_allowed_networks"] = archive_allowed_networks
            __props__.__dict__["cluster_id"] = cluster_id
            __props__.__dict__["direct_input_allowed_networks"] = direct_input_allowed_networks
            __props__.__dict__["query_allowed_networks"] = query_allowed_networks
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            __props__.__dict__["cluster_type"] = None
            __props__.__dict__["dedicated_input_pem"] = None
            __props__.__dict__["direct_input_pem"] = None
            __props__.__dict__["hostname"] = None
            __props__.__dict__["initial_archive_allowed_networks"] = None
            __props__.__dict__["initial_direct_input_allowed_networks"] = None
            __props__.__dict__["initial_query_allowed_networks"] = None
            __props__.__dict__["is_default"] = None
            __props__.__dict__["is_unlocked"] = None
            __props__.__dict__["region"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["dedicatedInputPem", "directInputPem", "initialArchiveAllowedNetworks", "initialDirectInputAllowedNetworks", "initialQueryAllowedNetworks"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(LogsCluster, __self__).__init__(
            'ovh:Dbaas/logsCluster:LogsCluster',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            archive_allowed_networks: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            cluster_id: Optional[pulumi.Input[builtins.str]] = None,
            cluster_type: Optional[pulumi.Input[builtins.str]] = None,
            dedicated_input_pem: Optional[pulumi.Input[builtins.str]] = None,
            direct_input_allowed_networks: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            direct_input_pem: Optional[pulumi.Input[builtins.str]] = None,
            hostname: Optional[pulumi.Input[builtins.str]] = None,
            initial_archive_allowed_networks: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            initial_direct_input_allowed_networks: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            initial_query_allowed_networks: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            is_default: Optional[pulumi.Input[builtins.bool]] = None,
            is_unlocked: Optional[pulumi.Input[builtins.bool]] = None,
            query_allowed_networks: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            region: Optional[pulumi.Input[builtins.str]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None) -> 'LogsCluster':
        """
        Get an existing LogsCluster resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] archive_allowed_networks: List of IP blocks
        :param pulumi.Input[builtins.str] cluster_id: Cluster ID. If not provided, the default cluster_id is used
        :param pulumi.Input[builtins.str] cluster_type: type of cluster (DEDICATED, PRO or TRIAL)
        :param pulumi.Input[builtins.str] dedicated_input_pem: PEM for dedicated inputs
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] direct_input_allowed_networks: List of IP blocks
        :param pulumi.Input[builtins.str] direct_input_pem: PEM for direct inputs
        :param pulumi.Input[builtins.str] hostname: cluster hostname hosting tenant
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] initial_archive_allowed_networks: Initial allowed networks for ARCHIVE flow type
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] initial_direct_input_allowed_networks: Initial allowed networks for DIRECT_INPUT flow type
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] initial_query_allowed_networks: Initial allowed networks for QUERY flow type
        :param pulumi.Input[builtins.bool] is_default: true if all content generated by given service will be placed on this cluster
        :param pulumi.Input[builtins.bool] is_unlocked: true if given service can perform advanced operations on cluster
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] query_allowed_networks: List of IP blocks
        :param pulumi.Input[builtins.str] region: datacenter localization
        :param pulumi.Input[builtins.str] service_name: The service name
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _LogsClusterState.__new__(_LogsClusterState)

        __props__.__dict__["archive_allowed_networks"] = archive_allowed_networks
        __props__.__dict__["cluster_id"] = cluster_id
        __props__.__dict__["cluster_type"] = cluster_type
        __props__.__dict__["dedicated_input_pem"] = dedicated_input_pem
        __props__.__dict__["direct_input_allowed_networks"] = direct_input_allowed_networks
        __props__.__dict__["direct_input_pem"] = direct_input_pem
        __props__.__dict__["hostname"] = hostname
        __props__.__dict__["initial_archive_allowed_networks"] = initial_archive_allowed_networks
        __props__.__dict__["initial_direct_input_allowed_networks"] = initial_direct_input_allowed_networks
        __props__.__dict__["initial_query_allowed_networks"] = initial_query_allowed_networks
        __props__.__dict__["is_default"] = is_default
        __props__.__dict__["is_unlocked"] = is_unlocked
        __props__.__dict__["query_allowed_networks"] = query_allowed_networks
        __props__.__dict__["region"] = region
        __props__.__dict__["service_name"] = service_name
        return LogsCluster(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="archiveAllowedNetworks")
    def archive_allowed_networks(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        List of IP blocks
        """
        return pulumi.get(self, "archive_allowed_networks")

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Cluster ID. If not provided, the default cluster_id is used
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter(name="clusterType")
    def cluster_type(self) -> pulumi.Output[builtins.str]:
        """
        type of cluster (DEDICATED, PRO or TRIAL)
        """
        return pulumi.get(self, "cluster_type")

    @property
    @pulumi.getter(name="dedicatedInputPem")
    def dedicated_input_pem(self) -> pulumi.Output[builtins.str]:
        """
        PEM for dedicated inputs
        """
        return pulumi.get(self, "dedicated_input_pem")

    @property
    @pulumi.getter(name="directInputAllowedNetworks")
    def direct_input_allowed_networks(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        List of IP blocks
        """
        return pulumi.get(self, "direct_input_allowed_networks")

    @property
    @pulumi.getter(name="directInputPem")
    def direct_input_pem(self) -> pulumi.Output[builtins.str]:
        """
        PEM for direct inputs
        """
        return pulumi.get(self, "direct_input_pem")

    @property
    @pulumi.getter
    def hostname(self) -> pulumi.Output[builtins.str]:
        """
        cluster hostname hosting tenant
        """
        return pulumi.get(self, "hostname")

    @property
    @pulumi.getter(name="initialArchiveAllowedNetworks")
    def initial_archive_allowed_networks(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        Initial allowed networks for ARCHIVE flow type
        """
        return pulumi.get(self, "initial_archive_allowed_networks")

    @property
    @pulumi.getter(name="initialDirectInputAllowedNetworks")
    def initial_direct_input_allowed_networks(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        Initial allowed networks for DIRECT_INPUT flow type
        """
        return pulumi.get(self, "initial_direct_input_allowed_networks")

    @property
    @pulumi.getter(name="initialQueryAllowedNetworks")
    def initial_query_allowed_networks(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        Initial allowed networks for QUERY flow type
        """
        return pulumi.get(self, "initial_query_allowed_networks")

    @property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> pulumi.Output[builtins.bool]:
        """
        true if all content generated by given service will be placed on this cluster
        """
        return pulumi.get(self, "is_default")

    @property
    @pulumi.getter(name="isUnlocked")
    def is_unlocked(self) -> pulumi.Output[builtins.bool]:
        """
        true if given service can perform advanced operations on cluster
        """
        return pulumi.get(self, "is_unlocked")

    @property
    @pulumi.getter(name="queryAllowedNetworks")
    def query_allowed_networks(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        List of IP blocks
        """
        return pulumi.get(self, "query_allowed_networks")

    @property
    @pulumi.getter
    def region(self) -> pulumi.Output[builtins.str]:
        """
        datacenter localization
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The service name
        """
        return pulumi.get(self, "service_name")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetServiceResult',
    'AwaitableGetServiceResult',
    'get_service',
    'get_service_output',
]

@pulumi.output_type
class GetServiceResult:
    """
    A collection of values returned by getService.
    """
    def __init__(__self__, can_be_terminated=None, country=None, description=None, id=None, ip=None, organisation_id=None, routed_tos=None, service_name=None, type=None):
        if can_be_terminated and not isinstance(can_be_terminated, bool):
            raise TypeError("Expected argument 'can_be_terminated' to be a bool")
        pulumi.set(__self__, "can_be_terminated", can_be_terminated)
        if country and not isinstance(country, str):
            raise TypeError("Expected argument 'country' to be a str")
        pulumi.set(__self__, "country", country)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ip and not isinstance(ip, str):
            raise TypeError("Expected argument 'ip' to be a str")
        pulumi.set(__self__, "ip", ip)
        if organisation_id and not isinstance(organisation_id, str):
            raise TypeError("Expected argument 'organisation_id' to be a str")
        pulumi.set(__self__, "organisation_id", organisation_id)
        if routed_tos and not isinstance(routed_tos, list):
            raise TypeError("Expected argument 'routed_tos' to be a list")
        pulumi.set(__self__, "routed_tos", routed_tos)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="canBeTerminated")
    def can_be_terminated(self) -> builtins.bool:
        """
        can be terminated
        """
        return pulumi.get(self, "can_be_terminated")

    @property
    @pulumi.getter
    def country(self) -> builtins.str:
        """
        country
        """
        return pulumi.get(self, "country")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Custom description on your ip
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ip(self) -> builtins.str:
        """
        ip block
        """
        return pulumi.get(self, "ip")

    @property
    @pulumi.getter(name="organisationId")
    def organisation_id(self) -> builtins.str:
        """
        IP block organisation Id
        """
        return pulumi.get(self, "organisation_id")

    @property
    @pulumi.getter(name="routedTos")
    def routed_tos(self) -> Sequence['outputs.GetServiceRoutedToResult']:
        """
        Routage information
        """
        return pulumi.get(self, "routed_tos")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        """
        Service where ip is routed to
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        """
        Possible values for ip type ( "cdn", "cloud", "dedicated", "failover", "hosted_ssl", "housing", "loadBalancing", "mail", "overthebox", "pcc", "pci", "private", "vpn", "vps", "vrack", "xdsl")
        """
        return pulumi.get(self, "type")


class AwaitableGetServiceResult(GetServiceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetServiceResult(
            can_be_terminated=self.can_be_terminated,
            country=self.country,
            description=self.description,
            id=self.id,
            ip=self.ip,
            organisation_id=self.organisation_id,
            routed_tos=self.routed_tos,
            service_name=self.service_name,
            type=self.type)


def get_service(service_name: Optional[builtins.str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetServiceResult:
    """
    Use this data source to retrieve information about an IP service.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    my_ip = ovh.Ip.get_service(service_name="XXXXXX")
    ```


    :param builtins.str service_name: The service name
    """
    __args__ = dict()
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:Ip/getService:getService', __args__, opts=opts, typ=GetServiceResult).value

    return AwaitableGetServiceResult(
        can_be_terminated=pulumi.get(__ret__, 'can_be_terminated'),
        country=pulumi.get(__ret__, 'country'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        ip=pulumi.get(__ret__, 'ip'),
        organisation_id=pulumi.get(__ret__, 'organisation_id'),
        routed_tos=pulumi.get(__ret__, 'routed_tos'),
        service_name=pulumi.get(__ret__, 'service_name'),
        type=pulumi.get(__ret__, 'type'))
def get_service_output(service_name: Optional[pulumi.Input[builtins.str]] = None,
                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetServiceResult]:
    """
    Use this data source to retrieve information about an IP service.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    my_ip = ovh.Ip.get_service(service_name="XXXXXX")
    ```


    :param builtins.str service_name: The service name
    """
    __args__ = dict()
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:Ip/getService:getService', __args__, opts=opts, typ=GetServiceResult)
    return __ret__.apply(lambda __response__: GetServiceResult(
        can_be_terminated=pulumi.get(__response__, 'can_be_terminated'),
        country=pulumi.get(__response__, 'country'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        ip=pulumi.get(__response__, 'ip'),
        organisation_id=pulumi.get(__response__, 'organisation_id'),
        routed_tos=pulumi.get(__response__, 'routed_tos'),
        service_name=pulumi.get(__response__, 'service_name'),
        type=pulumi.get(__response__, 'type')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['OkmsArgs', 'Okms']

@pulumi.input_type
class OkmsArgs:
    def __init__(__self__, *,
                 ovh_subsidiary: pulumi.Input[builtins.str],
                 region: pulumi.Input[builtins.str],
                 display_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Okms resource.
        :param pulumi.Input[builtins.str] ovh_subsidiary: OVH subsidiaries
        :param pulumi.Input[builtins.str] region: KMS region
        :param pulumi.Input[builtins.str] display_name: (String) Resource display name
        """
        pulumi.set(__self__, "ovh_subsidiary", ovh_subsidiary)
        pulumi.set(__self__, "region", region)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)

    @property
    @pulumi.getter(name="ovhSubsidiary")
    def ovh_subsidiary(self) -> pulumi.Input[builtins.str]:
        """
        OVH subsidiaries
        """
        return pulumi.get(self, "ovh_subsidiary")

    @ovh_subsidiary.setter
    def ovh_subsidiary(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "ovh_subsidiary", value)

    @property
    @pulumi.getter
    def region(self) -> pulumi.Input[builtins.str]:
        """
        KMS region
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        (String) Resource display name
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "display_name", value)


@pulumi.input_type
class _OkmsState:
    def __init__(__self__, *,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 iam: Optional[pulumi.Input['OkmsIamArgs']] = None,
                 kmip_endpoint: Optional[pulumi.Input[builtins.str]] = None,
                 ovh_subsidiary: Optional[pulumi.Input[builtins.str]] = None,
                 public_ca: Optional[pulumi.Input[builtins.str]] = None,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 rest_endpoint: Optional[pulumi.Input[builtins.str]] = None,
                 swagger_endpoint: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Okms resources.
        :param pulumi.Input[builtins.str] display_name: (String) Resource display name
        :param pulumi.Input['OkmsIamArgs'] iam: (Attributes) IAM resource metadata (see below for nested schema)
        :param pulumi.Input[builtins.str] kmip_endpoint: (String) KMS kmip API endpoint
        :param pulumi.Input[builtins.str] ovh_subsidiary: OVH subsidiaries
        :param pulumi.Input[builtins.str] public_ca: (String) KMS public CA (Certificate Authority)
        :param pulumi.Input[builtins.str] region: KMS region
        :param pulumi.Input[builtins.str] rest_endpoint: (String) KMS rest API endpoint
        :param pulumi.Input[builtins.str] swagger_endpoint: (String) KMS rest API swagger UI
        """
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if iam is not None:
            pulumi.set(__self__, "iam", iam)
        if kmip_endpoint is not None:
            pulumi.set(__self__, "kmip_endpoint", kmip_endpoint)
        if ovh_subsidiary is not None:
            pulumi.set(__self__, "ovh_subsidiary", ovh_subsidiary)
        if public_ca is not None:
            pulumi.set(__self__, "public_ca", public_ca)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if rest_endpoint is not None:
            pulumi.set(__self__, "rest_endpoint", rest_endpoint)
        if swagger_endpoint is not None:
            pulumi.set(__self__, "swagger_endpoint", swagger_endpoint)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        (String) Resource display name
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter
    def iam(self) -> Optional[pulumi.Input['OkmsIamArgs']]:
        """
        (Attributes) IAM resource metadata (see below for nested schema)
        """
        return pulumi.get(self, "iam")

    @iam.setter
    def iam(self, value: Optional[pulumi.Input['OkmsIamArgs']]):
        pulumi.set(self, "iam", value)

    @property
    @pulumi.getter(name="kmipEndpoint")
    def kmip_endpoint(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        (String) KMS kmip API endpoint
        """
        return pulumi.get(self, "kmip_endpoint")

    @kmip_endpoint.setter
    def kmip_endpoint(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kmip_endpoint", value)

    @property
    @pulumi.getter(name="ovhSubsidiary")
    def ovh_subsidiary(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        OVH subsidiaries
        """
        return pulumi.get(self, "ovh_subsidiary")

    @ovh_subsidiary.setter
    def ovh_subsidiary(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ovh_subsidiary", value)

    @property
    @pulumi.getter(name="publicCa")
    def public_ca(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        (String) KMS public CA (Certificate Authority)
        """
        return pulumi.get(self, "public_ca")

    @public_ca.setter
    def public_ca(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "public_ca", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        KMS region
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="restEndpoint")
    def rest_endpoint(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        (String) KMS rest API endpoint
        """
        return pulumi.get(self, "rest_endpoint")

    @rest_endpoint.setter
    def rest_endpoint(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rest_endpoint", value)

    @property
    @pulumi.getter(name="swaggerEndpoint")
    def swagger_endpoint(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        (String) KMS rest API swagger UI
        """
        return pulumi.get(self, "swagger_endpoint")

    @swagger_endpoint.setter
    def swagger_endpoint(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "swagger_endpoint", value)


@pulumi.type_token("ovh:Okms/okms:Okms")
class Okms(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 ovh_subsidiary: Optional[pulumi.Input[builtins.str]] = None,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        new_kms = ovh.okms.Okms("new_kms",
            ovh_subsidiary="FR",
            region="eu-west-rbx",
            display_name="terraformed KMS")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] display_name: (String) Resource display name
        :param pulumi.Input[builtins.str] ovh_subsidiary: OVH subsidiaries
        :param pulumi.Input[builtins.str] region: KMS region
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: OkmsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        new_kms = ovh.okms.Okms("new_kms",
            ovh_subsidiary="FR",
            region="eu-west-rbx",
            display_name="terraformed KMS")
        ```

        :param str resource_name: The name of the resource.
        :param OkmsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(OkmsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 ovh_subsidiary: Optional[pulumi.Input[builtins.str]] = None,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = OkmsArgs.__new__(OkmsArgs)

            __props__.__dict__["display_name"] = display_name
            if ovh_subsidiary is None and not opts.urn:
                raise TypeError("Missing required property 'ovh_subsidiary'")
            __props__.__dict__["ovh_subsidiary"] = ovh_subsidiary
            if region is None and not opts.urn:
                raise TypeError("Missing required property 'region'")
            __props__.__dict__["region"] = region
            __props__.__dict__["iam"] = None
            __props__.__dict__["kmip_endpoint"] = None
            __props__.__dict__["public_ca"] = None
            __props__.__dict__["rest_endpoint"] = None
            __props__.__dict__["swagger_endpoint"] = None
        super(Okms, __self__).__init__(
            'ovh:Okms/okms:Okms',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            display_name: Optional[pulumi.Input[builtins.str]] = None,
            iam: Optional[pulumi.Input[Union['OkmsIamArgs', 'OkmsIamArgsDict']]] = None,
            kmip_endpoint: Optional[pulumi.Input[builtins.str]] = None,
            ovh_subsidiary: Optional[pulumi.Input[builtins.str]] = None,
            public_ca: Optional[pulumi.Input[builtins.str]] = None,
            region: Optional[pulumi.Input[builtins.str]] = None,
            rest_endpoint: Optional[pulumi.Input[builtins.str]] = None,
            swagger_endpoint: Optional[pulumi.Input[builtins.str]] = None) -> 'Okms':
        """
        Get an existing Okms resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] display_name: (String) Resource display name
        :param pulumi.Input[Union['OkmsIamArgs', 'OkmsIamArgsDict']] iam: (Attributes) IAM resource metadata (see below for nested schema)
        :param pulumi.Input[builtins.str] kmip_endpoint: (String) KMS kmip API endpoint
        :param pulumi.Input[builtins.str] ovh_subsidiary: OVH subsidiaries
        :param pulumi.Input[builtins.str] public_ca: (String) KMS public CA (Certificate Authority)
        :param pulumi.Input[builtins.str] region: KMS region
        :param pulumi.Input[builtins.str] rest_endpoint: (String) KMS rest API endpoint
        :param pulumi.Input[builtins.str] swagger_endpoint: (String) KMS rest API swagger UI
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _OkmsState.__new__(_OkmsState)

        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["iam"] = iam
        __props__.__dict__["kmip_endpoint"] = kmip_endpoint
        __props__.__dict__["ovh_subsidiary"] = ovh_subsidiary
        __props__.__dict__["public_ca"] = public_ca
        __props__.__dict__["region"] = region
        __props__.__dict__["rest_endpoint"] = rest_endpoint
        __props__.__dict__["swagger_endpoint"] = swagger_endpoint
        return Okms(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[builtins.str]:
        """
        (String) Resource display name
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def iam(self) -> pulumi.Output['outputs.OkmsIam']:
        """
        (Attributes) IAM resource metadata (see below for nested schema)
        """
        return pulumi.get(self, "iam")

    @property
    @pulumi.getter(name="kmipEndpoint")
    def kmip_endpoint(self) -> pulumi.Output[builtins.str]:
        """
        (String) KMS kmip API endpoint
        """
        return pulumi.get(self, "kmip_endpoint")

    @property
    @pulumi.getter(name="ovhSubsidiary")
    def ovh_subsidiary(self) -> pulumi.Output[builtins.str]:
        """
        OVH subsidiaries
        """
        return pulumi.get(self, "ovh_subsidiary")

    @property
    @pulumi.getter(name="publicCa")
    def public_ca(self) -> pulumi.Output[builtins.str]:
        """
        (String) KMS public CA (Certificate Authority)
        """
        return pulumi.get(self, "public_ca")

    @property
    @pulumi.getter
    def region(self) -> pulumi.Output[builtins.str]:
        """
        KMS region
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="restEndpoint")
    def rest_endpoint(self) -> pulumi.Output[builtins.str]:
        """
        (String) KMS rest API endpoint
        """
        return pulumi.get(self, "rest_endpoint")

    @property
    @pulumi.getter(name="swaggerEndpoint")
    def swagger_endpoint(self) -> pulumi.Output[builtins.str]:
        """
        (String) KMS rest API swagger UI
        """
        return pulumi.get(self, "swagger_endpoint")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'PrivateDatabaseOrder',
    'PrivateDatabaseOrderDetail',
    'PrivateDatabasePlan',
    'PrivateDatabasePlanConfiguration',
    'PrivateDatabasePlanOption',
    'PrivateDatabasePlanOptionConfiguration',
    'GetPrivateDatabaseDbUserResult',
    'GetPrivateDatabaseUserDatabaseResult',
]

@pulumi.output_type
class PrivateDatabaseOrder(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "expirationDate":
            suggest = "expiration_date"
        elif key == "orderId":
            suggest = "order_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in PrivateDatabaseOrder. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        PrivateDatabaseOrder.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        PrivateDatabaseOrder.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 date: Optional[builtins.str] = None,
                 details: Optional[Sequence['outputs.PrivateDatabaseOrderDetail']] = None,
                 expiration_date: Optional[builtins.str] = None,
                 order_id: Optional[builtins.int] = None):
        """
        :param builtins.str date: date
        :param Sequence['PrivateDatabaseOrderDetailArgs'] details: Information about a Bill entry
        :param builtins.str expiration_date: expiration date
        :param builtins.int order_id: order id
        """
        if date is not None:
            pulumi.set(__self__, "date", date)
        if details is not None:
            pulumi.set(__self__, "details", details)
        if expiration_date is not None:
            pulumi.set(__self__, "expiration_date", expiration_date)
        if order_id is not None:
            pulumi.set(__self__, "order_id", order_id)

    @property
    @pulumi.getter
    def date(self) -> Optional[builtins.str]:
        """
        date
        """
        return pulumi.get(self, "date")

    @property
    @pulumi.getter
    def details(self) -> Optional[Sequence['outputs.PrivateDatabaseOrderDetail']]:
        """
        Information about a Bill entry
        """
        return pulumi.get(self, "details")

    @property
    @pulumi.getter(name="expirationDate")
    def expiration_date(self) -> Optional[builtins.str]:
        """
        expiration date
        """
        return pulumi.get(self, "expiration_date")

    @property
    @pulumi.getter(name="orderId")
    def order_id(self) -> Optional[builtins.int]:
        """
        order id
        """
        return pulumi.get(self, "order_id")


@pulumi.output_type
class PrivateDatabaseOrderDetail(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "orderDetailId":
            suggest = "order_detail_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in PrivateDatabaseOrderDetail. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        PrivateDatabaseOrderDetail.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        PrivateDatabaseOrderDetail.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 description: Optional[builtins.str] = None,
                 domain: Optional[builtins.str] = None,
                 order_detail_id: Optional[builtins.int] = None,
                 quantity: Optional[builtins.str] = None):
        """
        :param builtins.str description: Custom description on your privatedatabase order.
        :param builtins.str domain: expiration date
        :param builtins.int order_detail_id: order detail id
        :param builtins.str quantity: quantity
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if domain is not None:
            pulumi.set(__self__, "domain", domain)
        if order_detail_id is not None:
            pulumi.set(__self__, "order_detail_id", order_detail_id)
        if quantity is not None:
            pulumi.set(__self__, "quantity", quantity)

    @property
    @pulumi.getter
    def description(self) -> Optional[builtins.str]:
        """
        Custom description on your privatedatabase order.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def domain(self) -> Optional[builtins.str]:
        """
        expiration date
        """
        return pulumi.get(self, "domain")

    @property
    @pulumi.getter(name="orderDetailId")
    def order_detail_id(self) -> Optional[builtins.int]:
        """
        order detail id
        """
        return pulumi.get(self, "order_detail_id")

    @property
    @pulumi.getter
    def quantity(self) -> Optional[builtins.str]:
        """
        quantity
        """
        return pulumi.get(self, "quantity")


@pulumi.output_type
class PrivateDatabasePlan(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "planCode":
            suggest = "plan_code"
        elif key == "pricingMode":
            suggest = "pricing_mode"
        elif key == "catalogName":
            suggest = "catalog_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in PrivateDatabasePlan. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        PrivateDatabasePlan.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        PrivateDatabasePlan.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 duration: builtins.str,
                 plan_code: builtins.str,
                 pricing_mode: builtins.str,
                 catalog_name: Optional[builtins.str] = None,
                 configurations: Optional[Sequence['outputs.PrivateDatabasePlanConfiguration']] = None):
        """
        :param builtins.str duration: duration.
        :param builtins.str plan_code: Plan code.
        :param builtins.str pricing_mode: Pricing model identifier
        :param builtins.str catalog_name: Catalog name
        :param Sequence['PrivateDatabasePlanConfigurationArgs'] configurations: Representation of a configuration item for personalizing product
        """
        pulumi.set(__self__, "duration", duration)
        pulumi.set(__self__, "plan_code", plan_code)
        pulumi.set(__self__, "pricing_mode", pricing_mode)
        if catalog_name is not None:
            pulumi.set(__self__, "catalog_name", catalog_name)
        if configurations is not None:
            pulumi.set(__self__, "configurations", configurations)

    @property
    @pulumi.getter
    def duration(self) -> builtins.str:
        """
        duration.
        """
        return pulumi.get(self, "duration")

    @property
    @pulumi.getter(name="planCode")
    def plan_code(self) -> builtins.str:
        """
        Plan code.
        """
        return pulumi.get(self, "plan_code")

    @property
    @pulumi.getter(name="pricingMode")
    def pricing_mode(self) -> builtins.str:
        """
        Pricing model identifier
        """
        return pulumi.get(self, "pricing_mode")

    @property
    @pulumi.getter(name="catalogName")
    def catalog_name(self) -> Optional[builtins.str]:
        """
        Catalog name
        """
        return pulumi.get(self, "catalog_name")

    @property
    @pulumi.getter
    def configurations(self) -> Optional[Sequence['outputs.PrivateDatabasePlanConfiguration']]:
        """
        Representation of a configuration item for personalizing product
        """
        return pulumi.get(self, "configurations")


@pulumi.output_type
class PrivateDatabasePlanConfiguration(dict):
    def __init__(__self__, *,
                 label: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str label: Identifier of the resource
        :param builtins.str value: Path to the resource in API.OVH.COM
               
               Plan order valid values can be found on OVHcloud [APIv6](https://api.ovh.com/console/#/hosting/privateDatabase/availableOrderCapacities~GET)
        """
        pulumi.set(__self__, "label", label)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def label(self) -> builtins.str:
        """
        Identifier of the resource
        """
        return pulumi.get(self, "label")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        Path to the resource in API.OVH.COM

        Plan order valid values can be found on OVHcloud [APIv6](https://api.ovh.com/console/#/hosting/privateDatabase/availableOrderCapacities~GET)
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class PrivateDatabasePlanOption(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "planCode":
            suggest = "plan_code"
        elif key == "pricingMode":
            suggest = "pricing_mode"
        elif key == "catalogName":
            suggest = "catalog_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in PrivateDatabasePlanOption. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        PrivateDatabasePlanOption.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        PrivateDatabasePlanOption.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 duration: builtins.str,
                 plan_code: builtins.str,
                 pricing_mode: builtins.str,
                 catalog_name: Optional[builtins.str] = None,
                 configurations: Optional[Sequence['outputs.PrivateDatabasePlanOptionConfiguration']] = None):
        """
        :param builtins.str duration: Service duration
        :param builtins.str plan_code: Plan code
        :param builtins.str pricing_mode: Pricing model identifier
        :param builtins.str catalog_name: Catalog name
        :param Sequence['PrivateDatabasePlanOptionConfigurationArgs'] configurations: Representation of a configuration item for personalizing product
        """
        pulumi.set(__self__, "duration", duration)
        pulumi.set(__self__, "plan_code", plan_code)
        pulumi.set(__self__, "pricing_mode", pricing_mode)
        if catalog_name is not None:
            pulumi.set(__self__, "catalog_name", catalog_name)
        if configurations is not None:
            pulumi.set(__self__, "configurations", configurations)

    @property
    @pulumi.getter
    def duration(self) -> builtins.str:
        """
        Service duration
        """
        return pulumi.get(self, "duration")

    @property
    @pulumi.getter(name="planCode")
    def plan_code(self) -> builtins.str:
        """
        Plan code
        """
        return pulumi.get(self, "plan_code")

    @property
    @pulumi.getter(name="pricingMode")
    def pricing_mode(self) -> builtins.str:
        """
        Pricing model identifier
        """
        return pulumi.get(self, "pricing_mode")

    @property
    @pulumi.getter(name="catalogName")
    def catalog_name(self) -> Optional[builtins.str]:
        """
        Catalog name
        """
        return pulumi.get(self, "catalog_name")

    @property
    @pulumi.getter
    def configurations(self) -> Optional[Sequence['outputs.PrivateDatabasePlanOptionConfiguration']]:
        """
        Representation of a configuration item for personalizing product
        """
        return pulumi.get(self, "configurations")


@pulumi.output_type
class PrivateDatabasePlanOptionConfiguration(dict):
    def __init__(__self__, *,
                 label: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str label: Identifier of the resource
        :param builtins.str value: Path to the resource in API.OVH.COM
        """
        pulumi.set(__self__, "label", label)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def label(self) -> builtins.str:
        """
        Identifier of the resource
        """
        return pulumi.get(self, "label")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        Path to the resource in API.OVH.COM
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetPrivateDatabaseDbUserResult(dict):
    def __init__(__self__, *,
                 grant_type: builtins.str,
                 user_name: builtins.str):
        """
        :param builtins.str grant_type: Grant of this user for this database
        :param builtins.str user_name: User's name granted on this database
        """
        pulumi.set(__self__, "grant_type", grant_type)
        pulumi.set(__self__, "user_name", user_name)

    @property
    @pulumi.getter(name="grantType")
    def grant_type(self) -> builtins.str:
        """
        Grant of this user for this database
        """
        return pulumi.get(self, "grant_type")

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> builtins.str:
        """
        User's name granted on this database
        """
        return pulumi.get(self, "user_name")


@pulumi.output_type
class GetPrivateDatabaseUserDatabaseResult(dict):
    def __init__(__self__, *,
                 database_name: builtins.str,
                 grant_type: builtins.str):
        """
        :param builtins.str database_name: Database's name linked to this user
        :param builtins.str grant_type: Grant of this user for this database
        """
        pulumi.set(__self__, "database_name", database_name)
        pulumi.set(__self__, "grant_type", grant_type)

    @property
    @pulumi.getter(name="databaseName")
    def database_name(self) -> builtins.str:
        """
        Database's name linked to this user
        """
        return pulumi.get(self, "database_name")

    @property
    @pulumi.getter(name="grantType")
    def grant_type(self) -> builtins.str:
        """
        Grant of this user for this database
        """
        return pulumi.get(self, "grant_type")


